// Author 		: F. de la Parra
// Date			: March, 2019

package gtransport;

public class Vehicle  {
	// Note: private versions of attributes in the root class ('Vehicle')
	// with defined accessor methods are, in general, preferred to using
	// protected attributes.
	private int identifier; 
	private int year;
	private String make;
	private String fuelType;

	// Note: protected versions of the Vehicle's attributes can be 
	// accessed from derived classes without using accessor methods.	
	/*
	protected int identifier; 
	protected int year;
	protected String make;
	protected String fuelType;
	*/
	
	// enum to identify the acceptable fuel types.
	enum fuelTypeItem {GAS, ELECTRIC};
	
	// Default constructor.
	public Vehicle() {
		identifier = 0;
		year = 9999;
		make = "";
		fuelType = "gas";
	}
	
	// Full parameter constructor.
	public Vehicle(int id, int yyyy, String newMake, String fuel) {
		identifier = id;
		year = yyyy;
		make = newMake;
		try {
			fuelTypeItem tempFuelType = fuelTypeItem.valueOf(fuel.toUpperCase());
			fuelType = fuel;
		}
		catch(IllegalArgumentException e){
			System.out.println("\n'" + fuel + "' is an invalid fuel type! Program aborted!");
			System.exit(0);
		}
	}
	
	// Accessor methods
	
	public int getIdentifier() {
		return identifier;
	}
	
	public int getYear() {
		return year;
	}
	
	public String getMake() {
		return make;
	}
	
	public String getFuelType() {
		return fuelType;
	}
	
	// Optional Mutator methods
	// To declare here, if required by an application using the
	// 'Vehicle' class directly.
	
	
	// BEHAVIOUR METHODS.
	
	// Basic 'overrides' of methods in the 'Object' class.
	
	// Override of 'toString()' method in 'Object' class.
	public String toString() {
		return "id = " + identifier + ", year = " + year + ", make = " + make +
			   ", fuel = " + fuelType;
	}
	 
	// Override of 'equals()' method in 'Object' class.
	public boolean equals(Object otherObject) {
		if ((otherObject == null) ||
		   !(otherObject instanceof Vehicle))
		    return false;
		else {
			Vehicle otherVehicle = (Vehicle)otherObject;
			return identifier == otherVehicle.getIdentifier() &&
				   year == otherVehicle.getYear() &&
				   make.equals(otherVehicle.getMake()) &&
				   fuelType.equals(otherVehicle.getFuelType());
		}
	}
	
	// OTHER BEHAVIOUR METHODS.
	// To declare here, if required by an application using the
	// 'Vehicle' class directly.
}